==> jc-1.4.0.tar.gz: java/io/WriteAbortedException.h <==
// public class java.io.WriteAbortedException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class fd900dec397fa9a1 java_io_ObjectStreamException
// @dep_class da669b9d2576d29d java_io_WriteAbortedException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_ObjectStreamException

#include "java/io/ObjectStreamException.h"

#ifndef _JC_java_io_WriteAbortedException_H_
#define _JC_java_io_WriteAbortedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_io_WriteAbortedException$sub_refs	_jc_java_io_WriteAbortedException$sub_refs;
typedef struct _jc_java_io_WriteAbortedException$sub_nonrefs	_jc_java_io_WriteAbortedException$sub_nonrefs;
typedef struct _jc_java_io_WriteAbortedException$refs	_jc_java_io_WriteAbortedException$refs;
typedef struct _jc_java_io_WriteAbortedException$nonrefs	_jc_java_io_WriteAbortedException$nonrefs;
typedef struct _jc_java_io_WriteAbortedException$object	_jc_java_io_WriteAbortedException$object;

typedef struct _jc_java_io_WriteAbortedException$fields_struct	_jc_java_io_WriteAbortedException$fields_struct;
typedef const struct _jc_java_io_WriteAbortedException$vmethods	_jc_java_io_WriteAbortedException$vmethods;
typedef const struct _jc_java_io_WriteAbortedException$vtable	_jc_java_io_WriteAbortedException$vtable;
typedef const struct _jc_java_io_WriteAbortedException$vtype	_jc_java_io_WriteAbortedException$vtype;

// Class fields structure
struct _jc_java_io_WriteAbortedException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_io_WriteAbortedException$fields_struct _jc_java_io_WriteAbortedException$class_fields;

// Constructors
extern void _jc_java_io_WriteAbortedException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_io_WriteAbortedException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *);

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_io_WriteAbortedException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_io_WriteAbortedException$object *);
extern struct _jc_java_lang_String$object *_jc_java_io_WriteAbortedException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_io_WriteAbortedException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_io_WriteAbortedException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_io_WriteAbortedException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_io_WriteAbortedException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_io_WriteAbortedException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_io_WriteAbortedException$object *);
};

// Vtable
struct _jc_java_io_WriteAbortedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_io_ObjectStreamException$vmethods	java_io_ObjectStreamException;
	_jc_java_io_WriteAbortedException$vmethods	java_io_WriteAbortedException;
};

// Vtype
struct _jc_java_io_WriteAbortedException$vtype {
	_jc_type			type;
	_jc_java_io_WriteAbortedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_WriteAbortedException$sub_refs {
	struct _jc_java_lang_Exception$object	*detail;
};

// Reference instance fields (object)
struct _jc_java_io_WriteAbortedException$refs {
    _jc_java_io_WriteAbortedException$sub_refs	java_io_WriteAbortedException;
    _jc_java_io_ObjectStreamException$sub_refs	java_io_ObjectStreamException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_WriteAbortedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_WriteAbortedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_io_ObjectStreamException$sub_nonrefs	java_io_ObjectStreamException;
    _jc_java_io_WriteAbortedException$sub_nonrefs	java_io_WriteAbortedException;
};

// Object instance structure
struct _jc_java_io_WriteAbortedException$object {
	_jc_java_io_WriteAbortedException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_WriteAbortedException$vtype	*vtype;
	_jc_java_io_WriteAbortedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_WriteAbortedException$vtype _jc_java_io_WriteAbortedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_WriteAbortedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_WriteAbortedException$class_object;

#endif	/* _JC_java_io_WriteAbortedException_H_ */

==> jc-1.4.6.tar.gz: java/io/WriteAbortedException.h <==
// public class java.io.WriteAbortedException

// class file dependencies
// @dep_class 4e0a56550c69d57c java_io_IOException
// @dep_class fd900dec397fa9a1 java_io_ObjectStreamException
// @dep_class da669b9d2576d29d java_io_WriteAbortedException
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable

// header file dependencies
// @dep_header java_io_ObjectStreamException

#include "java/io/ObjectStreamException.h"

#ifndef _JC_java_io_WriteAbortedException_H_
#define _JC_java_io_WriteAbortedException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;
struct _jc_java_lang_Throwable$object;

// Typedefs
typedef struct _jc_java_io_WriteAbortedException$sub_refs	_jc_java_io_WriteAbortedException$sub_refs;
typedef struct _jc_java_io_WriteAbortedException$sub_nonrefs	_jc_java_io_WriteAbortedException$sub_nonrefs;
typedef struct _jc_java_io_WriteAbortedException$refs	_jc_java_io_WriteAbortedException$refs;
typedef struct _jc_java_io_WriteAbortedException$nonrefs	_jc_java_io_WriteAbortedException$nonrefs;
typedef struct _jc_java_io_WriteAbortedException$object	_jc_java_io_WriteAbortedException$object;

typedef struct _jc_java_io_WriteAbortedException$fields_struct	_jc_java_io_WriteAbortedException$fields_struct;
typedef const struct _jc_java_io_WriteAbortedException$vmethods	_jc_java_io_WriteAbortedException$vmethods;
typedef const struct _jc_java_io_WriteAbortedException$vtable	_jc_java_io_WriteAbortedException$vtable;
typedef const struct _jc_java_io_WriteAbortedException$vtype	_jc_java_io_WriteAbortedException$vtype;

// Class fields structure
struct _jc_java_io_WriteAbortedException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_io_WriteAbortedException$fields_struct _jc_java_io_WriteAbortedException$class_fields;

// Constructors
extern void _jc_java_io_WriteAbortedException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_java_io_WriteAbortedException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Throwable$object *_jc_java_io_WriteAbortedException$method$getCause$d5a96efc8523817a(_jc_env *, struct _jc_java_io_WriteAbortedException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_io_WriteAbortedException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_java_io_WriteAbortedException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_io_WriteAbortedException$method_info$getCause$d5a96efc8523817a;
extern _jc_method _jc_java_io_WriteAbortedException$method_info$getMessage$13aaf240efc902b1;

// Virtual methods structure
struct _jc_java_io_WriteAbortedException$vmethods {
	struct _jc_java_lang_Throwable$object	*(*getCause$d5a96efc8523817a)(_jc_env *, struct _jc_java_io_WriteAbortedException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_java_io_WriteAbortedException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_io_WriteAbortedException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_io_IOException$vmethods	java_io_IOException;
	_jc_java_io_ObjectStreamException$vmethods	java_io_ObjectStreamException;
	_jc_java_io_WriteAbortedException$vmethods	java_io_WriteAbortedException;
};

// Vtype
struct _jc_java_io_WriteAbortedException$vtype {
	_jc_type			type;
	_jc_java_io_WriteAbortedException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_io_WriteAbortedException$sub_refs {
	struct _jc_java_lang_Exception$object	*detail;
};

// Reference instance fields (object)
struct _jc_java_io_WriteAbortedException$refs {
    _jc_java_io_WriteAbortedException$sub_refs	java_io_WriteAbortedException;
    _jc_java_io_ObjectStreamException$sub_refs	java_io_ObjectStreamException;
    _jc_java_io_IOException$sub_refs	java_io_IOException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_io_WriteAbortedException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_io_WriteAbortedException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_io_IOException$sub_nonrefs	java_io_IOException;
    _jc_java_io_ObjectStreamException$sub_nonrefs	java_io_ObjectStreamException;
    _jc_java_io_WriteAbortedException$sub_nonrefs	java_io_WriteAbortedException;
};

// Object instance structure
struct _jc_java_io_WriteAbortedException$object {
	_jc_java_io_WriteAbortedException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_io_WriteAbortedException$vtype	*vtype;
	_jc_java_io_WriteAbortedException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_io_WriteAbortedException$vtype _jc_java_io_WriteAbortedException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_io_WriteAbortedException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_io_WriteAbortedException$class_object;

#endif	/* _JC_java_io_WriteAbortedException_H_ */
